%define _disable_ld_no_undefined 1

%define major   19
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d
%define strange_ver 4-2-0

Summary:        Server for sharing files and printers with Apple Macintosh
Name:           netatalk
Epoch:          4
Version:        4.2.0
Release:        %mkrel 1
License:        GPLv2+
Group:          System/Servers
Url:            https://netatalk.sourceforge.io/
Source0:        https://github.com/Netatalk/netatalk/releases/download/%{name}-%{strange_ver}/%{name}-%{version}.tar.xz
Source2:        netatalk.pam-system-auth
Source3:        netatalk.conf
Patch3:         netatalk-systemd-execstartpre.patch

BuildRequires:  meson
BuildRequires:  bison
BuildRequires:  chrpath
BuildRequires:  flex
BuildRequires:  localsearch
BuildRequires:  pam
BuildRequires:  cracklib-devel
BuildRequires:  db-devel
BuildRequires:  krb-devel
BuildRequires:  pam-devel
BuildRequires:  quota-devel
BuildRequires:  systemtap-sdt-devel
BuildRequires:  tcp_wrappers-devel
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libattr)
BuildRequires:  pkgconfig(libgcrypt)
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(avahi-core)
BuildRequires:  pkgconfig(iniparser)
BuildRequires:  pkgconfig(libdns_sd)
BuildRequires:  pkgconfig(libacl)
BuildRequires:  pkgconfig(ldap)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(talloc)
BuildRequires:  pkgconfig(tinysparql-3.0)

Requires:       pam
Requires:       python3-dbus
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
Netatalk is a freely-available Open Source AFP file server. It also provides a
kernel level implementation of the AppleTalk Protocol Suite. A *NIX/*BSD system
running Netatalk is capable of serving many Macintosh clients simultaneously
as an AppleShare file server (AFP), AppleTalk router, *NIX/*BSD print server,
and for accessing AppleTalk printers via Printer Access Protocol (PAP).
Included are a number of minor printing and debugging utilities.

%package -n %{libname}
Summary:        Runtime Library needed by %{name}
Group:          System/Libraries

%description -n %{libname}
Runtime librairy for %{name}.

%package -n %{devname}
Summary:        Development headers for %{name}
Group:          Development/C++
Requires:       %{libname} = %{epoch}:%{version}-%{release}
Provides:       %{name}-devel = %{epoch}:%{version}-%{release}
Provides:       lib%{name}-devel = %{epoch}:%{version}-%{release}

%description -n %{devname}
Headers files to build packages against %{name}.

%prep
%autosetup -p1

sed -i 's|dns_sd.h|avahi-compat-libdns_sd/dns_sd.h|' meson.build
sed -i 's|<dns_sd.h>|<avahi-compat-libdns_sd/dns_sd.h>|' etc/netatalk/afp_mdns.h

%build
%meson \
        --localstatedir=%{_sharedstatedir}                                     \
        -Ddefault_library=shared                                               \
        -Dwith-rpath=false                                                     \
        -Dwith-cracklib=true                                                   \
        -Dwith-krbV-uam=true                                                   \
        -Dwith-overwrite=true                                                  \
        -Dwith-pam=true                                                        \
        -Dwith-pam-path=%{_sysconfdir}/pam.d                                   \
        -Dwith-spotlight=true                                                  \
        -Dwith-lockfile-path=%{_rundir}/lock/netatalk/netatalk                 \
        -Dwith-tcp-wrappers=true                                               \
        -Dwith-dbus-sysconf-path=%{_datadir}/dbus-1/system.d                   \
        -Dwith-pkgconfdir-path=%{_sysconfdir}/netatalk                         \
        -Dwith-init-style=systemd                                              \
        -Dwith-init-hooks=false                                                \
        -Dwith-uams-path=%{_libdir}/netatalk                                   \
        -Dwith-cups=true                                                       \
        -Dwith-tests=true                                                      \
        -Dwith-testsuite=true                                                  \
        -Dwith-appletalk=false
%meson_build

%install
%meson_install

cp -fp %{SOURCE2} netatalk.pam-system-auth

# install our tmpfiles config
install -Dpm644 %{SOURCE3} %{buildroot}%{_tmpfilesdir}/netatalk.conf

# Fix python shebang
%py3_shebang_fix %{buildroot}%{_bindir}/afpstats

chrpath -d %{buildroot}%{_sbindir}/afpd %{buildroot}%{_libdir}/libatalk.so*

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%files
%license COPYING COPYRIGHT
%doc CONTRIBUTORS NEWS
%doc netatalk.pam-system-auth
%doc %{_pkgdocdir}/htmldocs/
%dir %{_sysconfdir}/netatalk
%config(noreplace) %{_sysconfdir}/netatalk/afp.conf
%config(noreplace) %{_sysconfdir}/netatalk/dbus-session.conf
%config(noreplace) %{_sysconfdir}/netatalk/extmap.conf
%config(noreplace) %{_sysconfdir}/pam.d/netatalk
%{_sbindir}/*
%{_bindir}/*
%{_mandir}/man*/*
%{_datadir}/netatalk/
%dir %{_libdir}/netatalk
%{_libdir}/netatalk/*.so
%{_unitdir}/netatalk.service
%{_tmpfilesdir}/netatalk.conf
%{_sharedstatedir}/netatalk
%{_datadir}/dbus-1/system.d/netatalk-dbus.conf

%files -n %{libname}
%license COPYING
%{_libdir}/libatalk.so.%{major}{,.*}

%files -n %{devname}
%doc %{_pkgdocdir}/DEVELOPER
%license COPYING
%{_includedir}/atalk/
%{_libdir}/libatalk.so


%changelog
* Tue Apr 01 2025 daviddavid <daviddavid> 4:4.2.0-1.mga10
+ Revision: 2172376
- new version: 4.2.0

* Sun Dec 29 2024 daviddavid <daviddavid> 4:4.0.8-1.mga10
+ Revision: 2131148
- new version: 4.0.8
- switch to meson build system

* Sun Dec 29 2024 daviddavid <daviddavid> 4:3.2.8-2.mga10
+ Revision: 2131071
- switch to new tinysparql replacement of tracker

* Sun Sep 15 2024 daviddavid <daviddavid> 4:3.2.8-1.mga10
+ Revision: 2096773
- new version: 3.2.8

* Wed Aug 28 2024 mrambo3501 <mrambo3501> 4:3.2.7-1.mga10
+ Revision: 2092074
- version 3.2.7
- fix Source0
- new major 18

* Tue Jul 16 2024 daviddavid <daviddavid> 4:3.2.3-1.mga10
+ Revision: 2081675
- new version: 3.2.3

* Tue Jul 09 2024 ns80 <ns80> 4:3.2.1-1.mga10
+ Revision: 2080456
- new version 3.2.1 for CVE-2024-38439 and CVE-2024-3844[01] (mga#33381)

* Thu Jun 06 2024 daviddavid <daviddavid> 4:3.2.0-1.mga10
+ Revision: 2070233
- new version: 3.2.0

* Thu May 30 2024 ns80 <ns80> 4:3.1.18-2.mga10
+ Revision: 2068720
- fix lockfile

* Tue May 28 2024 daviddavid <daviddavid> 4:3.1.18-1.mga10
+ Revision: 2068556
- new version: 3.1.18, fixes CVE-2022-22995 (mga#33249)
+ ns80 <ns80>
- add an upstream patch for CVE-2022-22995 (mga#33249)

* Mon Dec 18 2023 papoteur <papoteur> 4:3.1.14-3.mga10
+ Revision: 2019030
- Mass Rebuild - Python 3.12

* Thu Feb 02 2023 daviddavid <daviddavid> 4:3.1.14-2.mga9
+ Revision: 1937546
- add opensuse patch to fix CVE-2022-45188 (mga#31255)

* Sun Jan 29 2023 daviddavid <daviddavid> 4:3.1.14-1.mga9
+ Revision: 1936769
- new version: 3.1.14
- enable Spotlight support
- bundled libevent was removed upstream
- remove merged upstream patches

* Fri Sep 16 2022 neoclust <neoclust> 4:3.1.12-11.mga9
+ Revision: 1889164
- Rebuild against new openldap

* Thu Apr 14 2022 ns80 <ns80> 4:3.1.12-10.mga9
+ Revision: 1849350
- add upstream patches for CVE-2021-31439 and CVE-2022-2312[15] (mga#30287)

* Wed Apr 06 2022 umeabot <umeabot> 4:3.1.12-9.mga9
+ Revision: 1845721
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 4:3.1.12-8.mga9
+ Revision: 1747442
- rebuild for openssl 3.0.0

* Thu Dec 10 2020 luigiwalser <luigiwalser> 4:3.1.12-7.mga8
+ Revision: 1655074
- try building without tracker
+ joequant <joequant>
- fix build

* Thu Aug 06 2020 joequant <joequant> 4:3.1.12-6.mga8
+ Revision: 1611611
- set legacy

* Mon Mar 16 2020 daviddavid <daviddavid> 4:3.1.12-5.mga8
+ Revision: 1556627
- enable Spotlight support
- enable Zeroconf support

* Mon Mar 16 2020 daviddavid <daviddavid> 4:3.1.12-4.mga8
+ Revision: 1556608
- enable quota support
- enable dtrace support
- enable D-Bus support
- move uams path from atalk to netatalk
- remove no more needed 'nodlopen' ldflags hack

* Sun Feb 16 2020 daviddavid <daviddavid> 4:3.1.12-3.mga8
+ Revision: 1532193
- add patch to port afpstats to python3
- rebuild for new libevent 2.1.11
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Feb 01 2019 luigiwalser <luigiwalser> 4:3.1.12-2.mga7
+ Revision: 1362300
- config.example directory no longer exists

* Wed Dec 26 2018 daviddavid <daviddavid> 4:3.1.12-1.mga7
+ Revision: 1345095
- new version: 3.1.12, fixes CVE-2018-1160 (mga#24072)

* Sun Sep 23 2018 umeabot <umeabot> 4:3.1.11-3.mga7
+ Revision: 1299699
- Mageia 7 Mass Rebuild

* Mon Oct 09 2017 daviddavid <daviddavid> 4:3.1.11-2.mga7
+ Revision: 1170406
- add missing epoch

* Sat Sep 09 2017 guillomovitch <guillomovitch> 4:3.1.11-1.mga7
+ Revision: 1152204
- new version 3.1.11

* Fri Feb 12 2016 umeabot <umeabot> 4:2.2.3-11.mga6
+ Revision: 956238
- Mageia 6 Mass Rebuild

* Mon Sep 14 2015 fwang <fwang> 4:2.2.3-10.mga6
+ Revision: 879147
- rebuild for new libgcrypt

* Wed Oct 15 2014 umeabot <umeabot> 4:2.2.3-9.mga5
+ Revision: 750564
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4:2.2.3-8.mga5
+ Revision: 682840
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 4:2.2.3-7.mga4
+ Revision: 508291
- Mageia 4 Mass Rebuild
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 cjw <cjw> 4:2.2.3-5.mga3
+ Revision: 339685
- patch4: fix build with automake 1.13

* Sun Dec 16 2012 blino <blino> 4:2.2.3-4.mga3
+ Revision: 331340
- use rpm-helper service macros instead of hardcoded chkconfig (post fails since the service is now handled by systemd)

* Tue Jul 31 2012 fwang <fwang> 4:2.2.3-3.mga3
+ Revision: 276338
- rebuild for db-5.3

* Fri Jul 27 2012 fwang <fwang> 4:2.2.3-2.mga3
+ Revision: 274728
- update file list
- recognize db > 5.1

* Tue May 29 2012 shlomif <shlomif> 4:2.2.3-1.mga3
+ Revision: 248850
- New version: 2.2.3

* Sat Apr 28 2012 tmb <tmb> 4:2.2.1-2.mga2
+ Revision: 233810
- Require rpm-helper >= 0.24.8-1 for systemd support

* Fri Dec 09 2011 shlomif <shlomif> 4:2.2.1-1.mga2
+ Revision: 179580
- New version - 2.2.1

* Mon Dec 05 2011 shlomif <shlomif> 4:2.2.0-3.mga2
+ Revision: 177031
- Switch the -devel 'Group:' to a Mageia one
- Add a BuildRequires for krb-devel (it was missing)
- Bump the release
- Fix long lines, wrong group and other rpmlint problems
- Convert all tabs in the .spec to spaces.
- Replaced avahi-devel with avahi-core-devel. Add a sprintf-correction patch.
- imported package netatalk


* Fri Aug 19 2011 Jiri Skala <jskala@redhat.com> - 4:2.2.0-2
- fixes #726928 - BuildRequires: avahi-devel libacl-devel openldap-devel

* Fri Jul 29 2011 Jiri Skala <jskala@redhat.com> - 4:2.2.0-1
- update to latest upstream netatalk-2.2.0

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4:2.1.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jan 03 2011 Jiri Skala <jskala@redhat.com> - 4:2.1.5-1
- updated to latest upstream version netatalk-2.1.5

* Mon Oct 18 2010 Jiri Skala <jskala@redhat.com> - 4:2.1.4-1
- updated to latest upstream version

* Mon Jul 12 2010 Jiri Skala <jskala@redhat.com> - 4:2.1.3-1
- updated to latest upstream version
- added license texts to devel subpackage

* Wed Jun 30 2010 Jiri Skala <jskala@redhat.com> - 4:2.1.2-1
- updated to latest upstream version

* Fri May 28 2010 Jiri Skala <jskala@redhat.com> - 4:2.1.1-1
- updated to latest upstream version
- fixes #594999 - Summary and Description are old-fashioned
- renamed initscript
- initscript modified to be POSIX compliant

* Wed May 12 2010 Jiri Skala <jskala@redhat.com> - 4:2.1-1
- updated to latest upstream version

* Tue Nov 24 2009 Jiri Skala <jskala@redhat.com> - 4:2.0.5-2
- oops forgot upload new sources => shifted release number

* Tue Nov 24 2009 Jiri Skala <jskala@redhat.com> - 4:2.0.5-1
- updated to latest upstream version

* Mon Nov 23 2009 Jiri Skala <jskala@redhat.com> - 4:2.0.4-5
- added BuildRequires: ... libgcrypt-devel
- removed outdated atalk.init

* Tue Sep 15 2009 Jiri Skala <jskala@redhat.com> - 4:2.0.4-4
- fixed #473943

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 4:2.0.4-3
- rebuilt with new openssl

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4:2.0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jul 14 2009 Jiri Skala <jskala@redhat.com> - 4:2.0.4-1
- updated to latest upstream version

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4:2.0.3-27
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Feb 16 2009 Jiri Skala <jskala@redhat.com> -4:2.0.3-26
- Resolves #480641 - CVE-2008-5718 netatalk: papd command injection vulnerability

* Tue Jan 27 2009 Jiri Skala <jskala@redhat.com> -4:2.0.3-25
- fixed epoch in the subpackage requires

* Fri Jan 23 2009 Jiri Skala <jskala@redhat.com> -4:2.0.3-24
- fix #473186 conflict timeout with coreutils

* Sat Jan 17 2009 Tomas Mraz <tmraz@redhat.com> - 4:2.0.3-23
- rebuild with new openssl

* Wed Dec 03 2008 Jiri Skala <jskala@redhat.com> -4:2.0.3-22
- fix #473939 netatalk-2.0.3-21.fc10 disable quota

* Mon Oct 13 2008 Jiri Skala <jskala@redhat.com> - 4:2.0.3-21
- fix #465050 - FTBFS netatalk-2.0.3-19 - regenerated patches

* Mon Aug 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 4:2.0.3-20
- fix license tag

* Thu Mar 06 2008 Martin Nagy <mnagy@redhat.com> - 4:2.0.3-19
- fix chmod o+x (#225085)
- increase the maximum number of cnid_dbd processes to 512 (#232805)
- papd now writes debugging output to stderr when invoked with -d (#150021)
- fix multiarch conflict for netatalk-devel (#342681)

* Mon Feb 25 2008 Martin Nagy <mnagy@redhat.com> - 4:2.0.3-18
- make init script LSB compliant (#246993)

* Mon Feb 25 2008 Martin Nagy <mnagy@redhat.com> - 4:2.0.3-17
- fix unowned directories (#233889)

* Mon Feb 11 2008 Martin Nagy <mnagy@redhat.com> - 4:2.0.3-16
- rebuild for gcc-4.3

* Tue Dec 04 2007 Martin Nagy <mnagy@redhat.com> - 4:2.0.3-15.1
- rebuild

* Wed Sep 12 2007 Maros Barabas <mbarabas@redhat.com> -4:2.0.3-15
- patch to build on FC, bad open call 

* Tue Sep 11 2007 Maros Barabas <mbarabas@redhat.com> - 4:2.0.3-13
- rebuild

* Wed Aug 29 2007 Fedora Release Engineering <rel-eng at fedoraproject dot org> - 4:2.0.3-12
- Rebuild for selinux ppc32 issue.

* Thu May 10 2007 Maros Barabas <mbarabas@redhat.com> - 4:2.0.4-11
- fix from merge review
- Resolves #226190

* Tue Apr 17 2007 Maros Barabas <mbarabas@redhat.com> - 4:2.0.3-10
- fix fiew problems in spec

* Tue Jan 23 2007 Jindrich Novy <jnovy@redhat.com> - 4:2.0.3-9
- rebuild against new db4

* Mon Dec 04 2006 Maros Barabas	<mbarabas@redhat.com> - 4:2.0.3-8
- BuildRequires changed from cracklib to cracklib-devel

* Fri Aug 18 2006 Jesse Keating <jkeating@redhat.com> - 4:2.0.3-7
- rebuilt with latest binutils to pick up 64K -z commonpagesize on ppc*
  (#203001)
- Add dist tag

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 4:2.0.3-6.fc6.1
- rebuild

* Fri Jun 09 2006 Jason Vas Dias <jvdias@redhat.com> - 4:2.0.3-6.fc6
- rebuild for broken libgssapi deps and brew build

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 4:2.0.3-4.2.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jason Vas Dias <jvdias@redhat.com>
- rebuild for new gcc, glibc, glibc-kernheaders

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Wed Nov 09 2005 Jason Vas Dias <jvdias@redhat.com>
- Rebuild for new openssl dependencies

* Thu Oct 13 2005 Tomas Mraz <tmraz@redhat.com>
- use include instead of pam_stack in pam config

* Wed Jul 20 2005 Bill Nottingham <notting@redhat.com>
- don't run by default

* Thu Jun 16 2005 Jason Vas Dias <jvdias@redhat.com>
- Upgrade to upstream version 2.0.3
- fix bug 160486: use netatalk's initscript

* Wed Mar 30 2005 Florian La Roche <laroche@redhat.com>
- quick fix: rm -f /usr/include/netatalk/at.h until this
  is resolved the correct way

* Mon Mar 07 2005 Jason Vas Dias <jvdias@redhat.com>
- Fix for gcc4 compilation: extern_ucreator.patch

* Mon Feb 21 2005 Jason Vas Dias <jvdias@redhat.com>
- Upgraded to upstream version 2.0.2 .

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Wed Jan 07 2004 Florian La Roche <Florian.LaRoche@redhat.de>
- 1.6.4

* Fri Aug 1 2003 Charlie Bennett <ccb@redhat.com>
- Update with 1.6.3 upstream sources

* Tue Jul 29 2003 Elliot Lee <sopwith@redhat.com>
- Rebuild
- Fix perl multilib path editing
- Add pathcat patch

* Thu May  1 2003 Elliot Lee <sopwith@redhat.com> 1.5.5-7
- Make multilib generic
- Add builddep on quota (for rpcsvc/rquota.h)

* Wed Feb 18 2003 Bill Nottingham <notting@redhat.com> 1.5.5-5
- fix initscript error (#82118)

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Tue Jan  7 2003 Nalin Dahyabhai <nalin@redhat.com> 1.5.5-3
- patch for compile errors with new ssl libs
- rebuild

* Mon Dec 02 2002 Florian La Roche <Florian.LaRoche@redhat.de>
- postun should never fail

* Thu Nov 28 2002 Phil Knirsch <pknirsch@redhat.com> 1.5.5-1
- Updated to 1.5.5

* Tue Jun 25 2002 Phil Knirsch <pknirsch@redhat.com> 1.5.3.1-4
- Fixed dependancy problem on /usr/bin/rc by removing acleandir.[1|rc] (#67243)
- Fixed missing /usr/share/netatalk dir (#67222)

* Fri Jun 21 2002 Tim Powers <timp@redhat.com> 1.5.3.1-2
- automated rebuild

* Tue Jun 18 2002 Phil Knirsch <pknirsch@redhat.com> 1.5.3.1-1
- Updated to latest version 1.5.3.1.
- Fixed bug for nls file lookup (#66300).

* Mon May 27 2002 Phil Knirsch <pknirsch@redhat.com> 1.5.2-4
- Fixed initscript bug where you can't use blanks inside of names (#64926).

* Wed Apr 10 2002 Phil Knirsch <pknirsch@redhat.com> 1.5.2-3
- Fixed initscript to use correct config files from /etc/atalk (#62803)
- Changed initscript to use $0 instead of direct string (#61734)
- Change Copyright to Licencse and switch from BSD to GPL (#61746)

* Thu Mar 14 2002 Bill Nottingham <notting@redhat.com>
- don't run by default

* Wed Mar 13 2002 Bill Nottingham <notting@redhat.com>
- it's back 

* Fri Mar  2 2001 Tim Powers <timp@redhat.com>
- rebuilt against openssl-0.9.6-1

* Sun Feb 25 2001 Tim Powers <timp@redhat.com>
- fixed bug 29370. This package is trying to include a file glibc already includes

* Tue Jan 23 2001 Tim Powers <timp@redhat.com>
- updated initscript

* Thu Jan 04 2001 Than Ngo <than@redhat.com>
- fixed uams-path
- added noreplace to %%config

* Mon Nov 20 2000 Tim Powers <timp@redhat.com>
- rebuilt to fix bad dir perms

* Fri Nov 10 2000 Than Ngo <than@redhat.com>
- update to 1.5pre2 (bug #19737, #20397)
- update Url and ftp site
- clean up specfile
- netatalk-1.4b2+asun obsolete

* Mon Aug 07 2000 Than Ngo <than@redhat.de>
- fix dependency with glibc-devel (Bug #15589)
- fix typo in description (Bug #15479)

* Wed Aug 2 2000 Tim Powers <timp@redhat.com>
- fix symlinks not being relative.

* Fri Jul 28 2000 Than Ngo <than@redhat.de>
- add missing restart function in startup script

* Fri Jul 28 2000 Tim Powers <timp@redhat.com>
- fixed initscripts so that condrestart doesn't return 1 when the test fails

* Mon Jul 24 2000 Prospector <prospector@redhat.com>
- rebuilt

* Sun Jul 23 2000 Tim Powers <timp@redhat.com>
- rebuilt 

* Mon Jul 17 2000 Tim Powers <timp@redhat.com>
- inits back to rc.d/init.d, using service to start inits

* Wed Jul 12 2000 Than Ngo <than@redhat.de>
- rebuilt

* Thu Jul 06 2000 Tim Powers <timp@redhat.com>
- fixed broken PreReq, now PreReq's /etc/init.d

* Tue Jun 27 2000 Than Ngo <than@redhat.de>
- remove prereq initscripts, add requires initscripts
- clean up specfile

* Mon Jun 26 2000 Than Ngo <than@redhat.de>
- /etc/rc.d/init.d -> /etc/init.d
- add condrestart directive
- fix post/preun/postun scripts
- prereq initscripts >= 5.20

* Tue Jun 20 2000 Tim Powers <timp@redhat.com>
- fixed bug 11420 concerning the building with -O2.

* Thu Jun 8 2000 Tim Powers <timp@redhat.com>
- fix bug #11978 
- fix man page locations to be FHS compliant

* Thu Jun  1 2000 Nalin Dahyabhai <nalin@redhat.com>
- modify PAM setup to use system-auth

* Thu Dec 16 1999 Tim Powers <timp@redhat.com>
- renewed source so it is pristine, delete the problematic files in spec file
	instead
- general spec file cleanups, create buildroot and dirs in the %%install
	section
- strip binaries
- gzip man pages
- fixed netatalk-asun.librpcsvc.patch, -lnss_nis too
- changed group
- added %%defattr to %%files section

* Tue Aug 3 1999 iNOUE Koich! <inoue@ma.ns.musashi-tech.ac.jp>
- rpm-3.0 needs to remove vogus files from source.
  Removed files: etc/papd/.#magics.c, etc/.#diff
* Fri Jul 30 1999 iNOUE Koich! <inoue@ma.ns.musashi-tech.ac.jp>
- Change Copyright tag to BSD.
  Add /usr/bin/adv1tov2.
* Thu Apr 22 1999 iNOUE Koich! <inoue@ma.ns.musashi-tech.ac.jp>
- Correct librpcsvc.patch.  Move %%changelog section last.
  Uncomment again -DNEED_QUOTA_WRAPPER in sys/linux/Makefile since
  LinuxPPC may need.
* Wed Mar 31 1999 iNOUE Koich! <inoue@ma.ns.musashi-tech.ac.jp>
- Comment out -DNEED_QUOTA_WRAPPER in sys/linux/Makefile.
* Sat Mar 20 1999 iNOUE Koich! <inoue@ma.ns.musashi-tech.ac.jp>
- Correct symbolic links to psf.
  Remove asciize function from nbplkup so as to display Japanese hostname.
* Thu Mar 11 1999 iNOUE Koich! <inoue@ma.ns.musashi-tech.ac.jp>
- Included MacPerl 5 script ICDumpSuffixMap which dumps suffix mapping
  containd in Internet Config Preference.
* Tue Mar 2 1999 iNOUE Koich! <inoue@ma.ns.musashi-tech.ac.jp>
- [asun2.1.3]
* Mon Feb 15 1999 iNOUE Koich! <inoue@ma.ns.musashi-tech.ac.jp>
- [pre-asun2.1.2-8]
* Sun Feb 7 1999 iNOUE Koich! <inoue@ma.ns.musashi-tech.ac.jp>
- [pre-asun2.1.2-6]
* Mon Jan 25 1999 iNOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- [pre-asun2.1.2-3]
* Thu Dec 17 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- [pre-asun2.1.2]
  Remove crlf patch. It is now a server's option.
* Thu Dec 3 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Use stable version source netatalk-1.4b2+asun2.1.1.tar.gz
  Add uams directory
* Sat Nov 28 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Use pre-asun2.1.1-3 source.
* Mon Nov 23 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Use pre-asun2.1.1-2 source.
* Mon Nov 16 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Fix rcX.d's symbolic links.
* Wed Oct 28 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Use pre-asun2.1.0a-2 source. Remove '%%exclusiveos linux' line.
* Sat Oct 24 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Use stable version source netatalk-1.4b2+asun2.1.0.tar.gz.
* Mon Oct 5 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Use pre-asun2.1.0-10a source.
* Thu Sep 19 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Use pre-asun2.1.0-8 source. Add chkconfig support.
* Sat Sep 12 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Comment out -DCRLF. Use RPM_OPT_FLAGS.
* Mon Sep 8 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Use pre-asun2.1.0-7 source. Rename atalk.init to atalk.
* Mon Aug 22 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Use pre-asun2.1.0-6 source.
* Mon Jul 27 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Use pre-asun2.1.0-5 source.
* Tue Jul 21 1998 INOUE Koichi <inoue@ma.ns.musashi-techa.c.jp>
- Use pre-asun2.1.0-3 source.
* Tue Jul 7 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Add afpovertcp entries to /etc/services
- Remove BuildRoot in man8 pages
* Mon Jun 29 1998 INOUE Koichi <inoue@ma.ns.musashi-tech.ac.jp>
- Use modified sources 1.4b2+asun2.1.0 produced by Adrian Sun
  <asun@saul9.u.washington.edu> to provide an AppleShareIP file server
- Included AppleVolumes.system file maintained by Johnson
  <johnson@stpt.usf.edu>
* Mon Aug 25 1997 David Gibson <D.Gibson@student.anu.edu.au>
- Used a buildroot
- Use RPM_OPT_FLAGS
- Moved configuration parameters/files from atalk.init to /etc/atalk
- Separated devel package
- Built with shared libraries
* Sun Jul 13 1997 Paul H. Hargrove <hargrove@sccm.Stanford.EDU>
- Updated sources from 1.3.3 to 1.4b2
- Included endian patch for Linux/SPARC
- Use all the configuration files supplied in the source.  This has the
  following advantages over the ones in the previous rpm release:
	+ The printer 'lp' isn't automatically placed in papd.conf
	+ The default file conversion is binary rather than text.
- Automatically add and remove DDP services from /etc/services
- Placed the recommended /etc/services in the documentation
- Changed atalk.init to give daemons a soft kill
- Changed atalk.init to make configuration easier

* Wed May 28 1997 Mark Cornick <mcornick@zorak.gsfc.nasa.gov>
Updated for /etc/pam.d
